@@ -1,6 +1,7 @@
 package create
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"net/url"
@@ -8,8 +9,8 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/AlecAivazis/survey/v2"
 	"github.com/MakeNowJust/heredoc/v2"
+	"github.com/charmbracelet/huh"
 	"github.com/spf13/cobra"
 
 	gitlab "gitlab.com/gitlab-org/api/client-go"
@@ -23,7 +24,6 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/internal/iostreams"
 	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
-	"gitlab.com/gitlab-org/cli/internal/prompt"
 	"gitlab.com/gitlab-org/cli/internal/recovery"
 	"gitlab.com/gitlab-org/cli/internal/utils"
 )
@@ -88,7 +88,6 @@ func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 		gitlabClient:    f.GitLabClient,
 		config:          f.Config,
 		baseRepo:        f.BaseRepo,
-		headRepo:        ResolvedHeadRepo(f),
 		apiClient:       f.ApiClient,
 		defaultHostname: f.DefaultHostname(),
 	}
@@ -107,6 +106,8 @@ func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 		`),
 		Args: cobra.ExactArgs(0),
 		PreRun: func(cmd *cobra.Command, args []string) {
+			opts.headRepo = ResolvedHeadRepo(cmd.Context(), f)
+
 			repoOverride, _ := cmd.Flags().GetString("head")
 			if repoFromEnv := os.Getenv("GITLAB_HEAD_REPO"); repoOverride == "" && repoFromEnv != "" {
 				repoOverride = repoFromEnv
@@ -124,7 +125,7 @@ func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 			if err := opts.validate(cmd); err != nil {
 				return err
 			}
-			if err := opts.run(); err != nil {
+			if err := opts.run(cmd.Context()); err != nil {
 				// always save options to file
 				recoverErr := createRecoverSaveFile(opts)
 				if recoverErr != nil {
@@ -218,7 +219,7 @@ func parseIssue(apiClientFunc func(repoHost string) (*api.Client, error), gitlab
 	return issue, nil
 }
 
-func (o *options) run() error {
+func (o *options) run(ctx context.Context) error {
 	out := o.io.StdOut
 	c := o.io.Color()
 	mrCreateOpts := &gitlab.CreateMergeRequestOptions{}
@@ -294,7 +295,7 @@ func (o *options) run() error {
 
 	headRepoRemote, err := repoRemote(o, headRepo, o.SourceProject, "glab-head")
 	if err != nil {
-		return nil
+		return err
 	}
 
 	var baseRepoRemote *glrepo.Remote
@@ -305,7 +306,7 @@ func (o *options) run() error {
 	} else {
 		baseRepoRemote, err = repoRemote(o, baseRepo, o.TargetProject, "glab-base")
 		if err != nil {
-			return nil
+			return err
 		}
 	}
 
@@ -389,14 +390,11 @@ func (o *options) run() error {
 			var templateContents string
 			if o.Description == "" {
 				if o.noEditor {
-					err = prompt.AskMultiline(&o.Description, "description", "Description:", "")
+					err = o.io.Multiline(ctx, &o.Description, "Description:", "")
 					if err != nil {
 						return err
 					}
 				} else {
-					templateResponse := struct {
-						Index int
-					}{}
 					templateNames, err := cmdutils.ListGitLabTemplates(cmdutils.MergeRequestTemplate)
 					if err != nil {
 						return fmt.Errorf("error getting templates: %w", err)
@@ -408,21 +406,9 @@ func (o *options) run() error {
 					templateNames = append(templateNames, mrWithCommitsTemplate)
 					templateNames = append(templateNames, mrEmptyTemplate)
 
-					selectQs := []*survey.Question{
-						{
-							Name: "index",
-							Prompt: &survey.Select{
-								Message: "Choose a template:",
-								Options: templateNames,
-							},
-						},
-					}
-
-					if err := prompt.Ask(selectQs, &templateResponse); err != nil {
+					if err := o.io.Select(ctx, &templateName, "Choose a template:", templateNames); err != nil {
 						return fmt.Errorf("could not prompt: %w", err)
 					}
-
-					templateName = templateNames[templateResponse.Index]
 					switch templateName {
 					case mrWithCommitsTemplate:
 						// templateContents should be filled from commit messages
@@ -453,27 +439,57 @@ func (o *options) run() error {
 				}
 			}
 
-			if o.Title == "" {
-				err = prompt.AskQuestionWithInput(&o.Title, "title", "Title:", "", true)
-				if err != nil {
-					return err
-				}
+			// Combine Title + Description into a single form
+			var fields []huh.Field
+			needsTitle := o.Title == ""
+			needsDescription := o.Description == ""
+
+			if needsTitle {
+				fields = append(fields, huh.NewInput().
+					Title("Title").
+					Value(&o.Title).
+					Validate(func(s string) error {
+						if s == "" {
+							return fmt.Errorf("title is required")
+						}
+						return nil
+					}))
 			}
-			if o.Description == "" {
+
+			if needsDescription {
 				if o.noEditor {
-					err = prompt.AskMultiline(&o.Description, "description", "Description:", "")
-					if err != nil {
-						return err
-					}
+					fields = append(fields, huh.NewText().
+						Title("Description").
+						Value(&o.Description))
 				} else {
 					editor, err := cmdutils.GetEditor(o.config)
 					if err != nil {
 						return err
 					}
-					err = cmdutils.EditorPrompt(&o.Description, "Description", templateContents, editor)
-					if err != nil {
-						return err
+
+					if templateContents != "" {
+						o.Description = templateContents
 					}
+
+					textField := huh.NewText().
+						Title("Description").
+						Value(&o.Description).
+						ExternalEditor(true).
+						EditorExtension(".md")
+
+					if editor != "" {
+						textField = textField.Editor(editor)
+					}
+
+					fields = append(fields, textField)
+				}
+			}
+
+			// Run the combined form
+			if len(fields) > 0 {
+				err = o.io.RunForm(ctx, fields...)
+				if err != nil {
+					return err
 				}
 			}
 		}
@@ -537,7 +553,7 @@ func (o *options) run() error {
 	}
 
 	if action == cmdutils.NoAction {
-		action, err = cmdutils.ConfirmSubmission(o.io, true)
+		action, err = cmdutils.ConfirmSubmission(ctx, o.io, true)
 		if err != nil {
 			return fmt.Errorf("unable to confirm: %w", err)
 		}
@@ -552,14 +568,14 @@ func (o *options) run() error {
 		}
 		var metadataActions []string
 
-		err := prompt.MultiSelect(&metadataActions, "metadata", "Which metadata types to add?", metadataOptions)
+		err := o.io.MultiSelect(ctx, &metadataActions, "Which metadata types to add?", metadataOptions)
 		if err != nil {
 			return fmt.Errorf("failed to pick the metadata to add: %w", err)
 		}
 
 		for _, x := range metadataActions {
 			if x == "labels" {
-				err = cmdutils.LabelsPrompt(&o.Labels, client, baseRepoRemote)
+				err = cmdutils.LabelsPrompt(ctx, o.io, &o.Labels, client, baseRepoRemote)
 				if err != nil {
 					return err
 				}
@@ -567,13 +583,13 @@ func (o *options) run() error {
 			if x == "assignees" {
 				// Use minimum permission level 30 (Maintainer) as it is the minimum level
 				// to accept a merge request
-				err = cmdutils.UsersPrompt(&o.Assignees, client, baseRepoRemote, o.io, 30, x)
+				err = cmdutils.UsersPrompt(ctx, &o.Assignees, client, baseRepoRemote, o.io, 30, x)
 				if err != nil {
 					return err
 				}
 			}
 			if x == "milestones" {
-				err = cmdutils.MilestonesPrompt(&o.Milestone, client, baseRepoRemote, o.io)
+				err = cmdutils.MilestonesPrompt(ctx, &o.Milestone, client, baseRepoRemote, o.io)
 				if err != nil {
 					return err
 				}
@@ -581,7 +597,7 @@ func (o *options) run() error {
 			if x == "reviewers" {
 				// Use minimum permission level 30 (Maintainer) as it is the minimum level
 				// to accept a merge request
-				err = cmdutils.UsersPrompt(&o.Reviewers, client, baseRepoRemote, o.io, 30, x)
+				err = cmdutils.UsersPrompt(ctx, &o.Reviewers, client, baseRepoRemote, o.io, 30, x)
 				if err != nil {
 					return err
 				}
@@ -589,7 +605,7 @@ func (o *options) run() error {
 		}
 
 		// Ask the user again but don't permit AddMetadata a second time
-		action, err = cmdutils.ConfirmSubmission(o.io, false)
+		action, err = cmdutils.ConfirmSubmission(ctx, o.io, false)
 		if err != nil {
 			return err
 		}
@@ -784,7 +800,7 @@ func generateMRCompareURL(opts *options) (string, error) {
 	return u.String(), nil
 }
 
-func ResolvedHeadRepo(f cmdutils.Factory) func() (glrepo.Interface, error) {
+func ResolvedHeadRepo(ctx context.Context, f cmdutils.Factory) func() (glrepo.Interface, error) {
 	return func() (glrepo.Interface, error) {
 		client, err := f.GitLabClient()
 		if err != nil {
@@ -798,7 +814,7 @@ func ResolvedHeadRepo(f cmdutils.Factory) func() (glrepo.Interface, error) {
 		if err != nil {
 			return nil, err
 		}
-		headRepo, err := repoContext.HeadRepo(f.IO())
+		headRepo, err := repoContext.HeadRepo(ctx, f.IO())
 		if err != nil {
 			return nil, err
 		}
