@@ -1,18 +1,18 @@
 package reorder
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"reflect"
 	"slices"
 	"strings"
 
-	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
-
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 
 	gitlab "gitlab.com/gitlab-org/api/client-go"
+
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/auth"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
@@ -20,6 +20,7 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/git"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/internal/iostreams"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 	"gitlab.com/gitlab-org/cli/internal/text"
 )
 
@@ -51,13 +52,13 @@ func NewCmdReorderStack(f cmdutils.Factory, gr git.GitRunner, getText cmdutils.G
 			opts.io.StartSpinner("Reordering\n")
 			defer opts.io.StopSpinner("%s Reordering complete\n", f.IO().Color().GreenCheck())
 
-			return opts.run(f, getText)
+			return opts.run(cmd.Context(), f, getText)
 		},
 	}
 	return stackSaveCmd
 }
 
-func (o *options) run(f cmdutils.Factory, getText cmdutils.GetTextUsingEditor) error {
+func (o *options) run(ctx context.Context, f cmdutils.Factory, getText cmdutils.GetTextUsingEditor) error {
 	o.io.StartSpinner("Reordering\n")
 	defer o.io.StopSpinner("")
 
@@ -79,7 +80,7 @@ func (o *options) run(f cmdutils.Factory, getText cmdutils.GetTextUsingEditor) e
 	o.io.StopSpinner("")
 	// pausing the spinner in case it's a terminal based editor
 
-	branches, err := promptForOrder(f, getText, stack, ref.Branch)
+	branches, err := promptForOrder(ctx, f, getText, stack, ref.Branch)
 	if err != nil {
 		return fmt.Errorf("error getting new branch order: %v", err)
 	}
@@ -102,7 +103,7 @@ func (o *options) run(f cmdutils.Factory, getText cmdutils.GetTextUsingEditor) e
 	}
 	o.labClient = client
 
-	err = updateMRs(f, updatedStack, stack)
+	err = updateMRs(ctx, f, updatedStack, stack)
 	if err != nil {
 		return fmt.Errorf("error updating merge requests: %v", err)
 	}
@@ -182,7 +183,7 @@ func matchBranchesToStack(stack git.Stack, branches []string) (git.Stack, error)
 	return newStack, nil
 }
 
-func updateMRs(f cmdutils.Factory, newStack git.Stack, oldStack git.Stack) error {
+func updateMRs(ctx context.Context, f cmdutils.Factory, newStack git.Stack, oldStack git.Stack) error {
 	for _, ref := range newStack.Iter2() {
 		// if there is already an MR and the order has been adjusted
 		if ref.MR != "" &&
@@ -194,7 +195,7 @@ func updateMRs(f cmdutils.Factory, newStack git.Stack, oldStack git.Stack) error
 				return fmt.Errorf("error connecting to GitLab: %v", err)
 			}
 
-			mr, _, err := mrutils.MRFromArgsWithOpts(f, []string{ref.Branch}, nil, "opened")
+			mr, _, err := mrutils.MRFromArgsWithOpts(ctx, f, []string{ref.Branch}, nil, "opened")
 			if err != nil {
 				return fmt.Errorf("error getting merge request from GitLab: %v", err)
 			}
