@@ -1,17 +1,16 @@
 package sync
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"strings"
 
-	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
-
 	"github.com/MakeNowJust/heredoc/v2"
-	gitlab "gitlab.com/gitlab-org/api/client-go"
-
 	"github.com/spf13/cobra"
 
+	gitlab "gitlab.com/gitlab-org/api/client-go"
+
 	"gitlab.com/gitlab-org/cli/internal/auth"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/commands/mr/create"
@@ -20,6 +19,7 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/git"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/internal/iostreams"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 	"gitlab.com/gitlab-org/cli/internal/text"
 )
 
@@ -75,14 +75,14 @@ func NewCmdSyncStack(f cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 
 			var gr git.StandardGitCommand
 
-			return opts.run(f, gr)
+			return opts.run(cmd.Context(), f, gr)
 		},
 	}
 
 	return stackSaveCmd
 }
 
-func (o *options) run(f cmdutils.Factory, gr git.GitRunner) error {
+func (o *options) run(ctx context.Context, f cmdutils.Factory, gr git.GitRunner) error {
 	client, err := auth.GetAuthenticatedClient(f.Config(), f.GitLabClient, f.IO())
 	if err != nil {
 		return fmt.Errorf("error authorizing with GitLab: %v", err)
@@ -98,7 +98,7 @@ func (o *options) run(f cmdutils.Factory, gr git.GitRunner) error {
 
 	// This prompts the user for the head repo if they're in a fork,
 	// allowing them to choose between their fork and the original repository
-	source, err := create.ResolvedHeadRepo(f)()
+	source, err := create.ResolvedHeadRepo(ctx, f)()
 	if err != nil {
 		return fmt.Errorf("error determining head repo: %v", err)
 	}
@@ -161,7 +161,7 @@ func (o *options) run(f cmdutils.Factory, gr git.GitRunner) error {
 			}
 		} else {
 			// we found an MR. let's get the status:
-			mr, _, err := mrutils.MRFromArgsWithOpts(f, []string{ref.Branch}, nil, "any")
+			mr, _, err := mrutils.MRFromArgsWithOpts(ctx, f, []string{ref.Branch}, nil, "any")
 			if err != nil {
 				return fmt.Errorf("error getting merge request from branch: %v. Does it still exist?", err)
 			}
@@ -304,15 +304,19 @@ func createMR(client *gitlab.Client, opts *options, ref *git.StackRef, gr git.Gi
 		previousBranch = opts.stack.Refs[ref.Prev].Branch
 	}
 
+	parts := strings.SplitN(ref.Description, "\n", 2)
+	title := strings.TrimSpace(parts[0])
+	if len(title) > maxMRTitleSize {
+		title = title[0:68] + "..."
+	}
 	var description string
-	if len(ref.Description) > maxMRTitleSize {
-		description = ref.Description[0:68] + "..."
-	} else {
-		description = ref.Description
+	if len(parts) > 1 {
+		description = strings.TrimSpace(parts[1])
 	}
 
 	l := &gitlab.CreateMergeRequestOptions{
-		Title:              gitlab.Ptr(description),
+		Title:              gitlab.Ptr(title),
+		Description:        gitlab.Ptr(description),
 		SourceBranch:       gitlab.Ptr(ref.Branch),
 		TargetBranch:       gitlab.Ptr(previousBranch),
 		AssigneeID:         gitlab.Ptr(opts.user.ID),
